////////////////////////////////////////////////////////////////////////////////
// Mechanical trade system for MetaTrader 5                                   //
// Copyright (c) 2010 Interesting, Extern.Fx                                  //
////////////////////////////////////////////////////////////////////////////////
// Module of the object class (CMqlHeikenAshi)                                //
// Module: UCMqlHeikenAshi - Class (CMqlHeikenAshi)                           //
////////////////////////////////////////////////////////////////////////////////
// Version:      1.0                                                          //
// Version File: 1.0.0.0                                                      //
// File name: UCMqlHeikenAshi.mqh                                             //
////////////////////////////////////////////////////////////////////////////////
//                                  Property                                  //
////////////////////////////////////////////////////////////////////////////////
#property description "Class (CMqlHeikenAshi)"
#property description "Version File: 1.0.0.0"
#property copyright   "Copyright 2010, Interesting, Extern.Fx"
#property link        "http://www.mql5.com/ru/"
////////////////////////////////////////////////////////////////////////////////
//                            The strings resource                            //
////////////////////////////////////////////////////////////////////////////////
string MsgErrorHandle = "   Heiken Ashi #: %d";

string MsgErrorCopyOpen = "   Open[] #: %d";
string MsgErrorCopyHigh = "   High[] #: %d";
string MsgErrorCopyLow = "   Low[] #: %d";
string MsgErrorCopyClose = "   Close[] #: %d";
////////////////////////////////////////////////////////////////////////////////
//                           Class (CMqlHeikenAshi)                           //
////////////////////////////////////////////////////////////////////////////////
//Class CMqlHeikenAshi
class CMqlHeikenAshi
//Base class of the object "Heiken-Ashi"
{
//----------------------------------------------------------------------------//
protected:
//****************************************************************************//
//                    Protected declarations of the class                     //
//****************************************************************************//
//----------------------------------------------------------------------------//
//                    Protected variables for object class                    //
//----------------------------------------------------------------------------//
//Handle
int Handle;
//Symbol and Period
ENUM_TIMEFRAMES WorkPeriod;
string WorkSymbol;
//Size buffers of the array
int BuffersSize;
//----------------------------------------------------------------------------//
//                     Protected arrays for object class                      //
//----------------------------------------------------------------------------//
double ArrOpen[];
double ArrHigh[];
double ArrLow[];
double ArrClose[];
//----------------------------------------------------------------------------//
public:
//****************************************************************************//
//                      Public declarations of the class                      //
//****************************************************************************//
//----------------------------------------------------------------------------//
//                         Constructor and Destructor                         //
//----------------------------------------------------------------------------//
//Constructor of the class
void CMqlHeikenAshi();
bool Create(string symbol, ENUM_TIMEFRAMES timeframe,int ArrSize=32);
//Destructor of the class
void ~CMqlHeikenAshi();
//----------------------------------------------------------------------------//
//                         Public methods of the class                        //
//----------------------------------------------------------------------------//

//Copying data from buffer of the indicator
bool CopyData();

//  Open, High, Low  Close
double GetOpen(int shift);
double GetHigh(int shift);
double GetLow(int shift);
double GetClose(int shift);

//   
ENUM_TIMEFRAMES GetTimeframe();
string GetSymbol();

string GetTimeframeName();
//----------------------------------------------------------------------------//
};
////////////////////////////////////////////////////////////////////////////////
//                               Implementation                               //
////////////////////////////////////////////////////////////////////////////////
//****************************************************************************//
//                    Protected declarations of the class                     //
//****************************************************************************//

//****************************************************************************//
//                      Public declarations of the class                      //
//****************************************************************************//
//----------------------------------------------------------------------------//
//                         Constructor and Destructor                         //
//----------------------------------------------------------------------------//
//Constructor CMqlHeikenAshi.CMqlHeikenAshi
void CMqlHeikenAshi::CMqlHeikenAshi()
{
//----------------------------------------------------------------------------//
//Work variables
//----------------------------------------------------------------------------//

Handle = 0;

//   
ArraySetAsSeries(ArrOpen, true);
ArraySetAsSeries(ArrHigh, true);
ArraySetAsSeries(ArrLow, true);
ArraySetAsSeries(ArrClose, true);
//----------------------------------------------------------------------------//
}
//****************************************************************************//
//Constructor CMqlHeikenAshi.Create
bool CMqlHeikenAshi::Create(string symbol="", ENUM_TIMEFRAMES timeframe = 0,int ArrSize=32)
{
//----------------------------------------------------------------------------//
//Work variables
bool Result; //Returned importance
//----------------------------------------------------------------------------//

Result = true;

//Checking parameters
  if(symbol=="") symbol= _Symbol;
  
  if(ArrSize>0)BuffersSize = ArrSize; else BuffersSize = 32;

//Changing  dimensionality for arrays
ArrayResize(ArrOpen,BuffersSize);
ArrayResize(ArrHigh,BuffersSize);
ArrayResize(ArrLow,BuffersSize);
ArrayResize(ArrClose,BuffersSize);

//Symbol and Period
WorkPeriod = timeframe;
WorkSymbol = symbol;

//Handle for Heiken-Ashi
Handle = iCustom(WorkSymbol,WorkPeriod,"Examples\\Heiken_Ashi"); //iRSI(WorkSymbol,WorkPeriod,5,PRICE_CLOSE)

  if(Handle == INVALID_HANDLE)
  {
  PrintFormat(MsgErrorHandle,GetLastError());
  Result = false;
  }
//----------------------------------------------------------------------------//
return(Result);
//----------------------------------------------------------------------------//
}
//****************************************************************************//
//Destructor CMqlHeikenAshi.~CMqlHeikenAshi
void CMqlHeikenAshi::~CMqlHeikenAshi()
{
//----------------------------------------------------------------------------//
//Work variables
//----------------------------------------------------------------------------//

  if(Handle!= INVALID_HANDLE) IndicatorRelease(Handle);

//----------------------------------------------------------------------------//
}
//----------------------------------------------------------------------------//
//                         Public methods of the class                        //
//----------------------------------------------------------------------------//
//Constructor CMqlHeikenAshi.CopyData
bool CMqlHeikenAshi::CopyData()
{
//----------------------------------------------------------------------------//
//Work variables
//----------------------------------------------------------------------------//

//Check correctness of the handle
  if(Handle == INVALID_HANDLE)
  {
  PrintFormat(MsgErrorHandle,GetLastError());
  return(false);
  }
//Copying operational data
  
  if(CopyBuffer(Handle,0,0,BuffersSize,ArrOpen )< 0)
  //Copying of the prices of the opening
  {
  PrintFormat(MsgErrorCopyOpen,GetLastError());
  return(false);
  }

  if(CopyBuffer(Handle,0,0,BuffersSize,ArrHigh)<0)
  //Copying of the maximum prices
  {
  PrintFormat(MsgErrorCopyHigh,GetLastError());
  return( false );
  }

  if(CopyBuffer(Handle,2,0,BuffersSize,ArrLow)<0)
  //Copying of the minimum prices
  {
  PrintFormat(MsgErrorCopyLow,GetLastError());
  return( false );
  }

  if(CopyBuffer(Handle,3,0,BuffersSize,ArrClose)<0)
  //  
  {
  PrintFormat(MsgErrorCopyClose,GetLastError());
  return(false);
  }
//----------------------------------------------------------------------------//
return(true);
//----------------------------------------------------------------------------//
}
//****************************************************************************//
//Function CMqlHeikenAshi.GetOpen
double CMqlHeikenAshi::GetOpen(int shift)
{
return(ArrOpen[shift]);
}
//****************************************************************************//
//Function CMqlHeikenAshi.GetHigh
double CMqlHeikenAshi::GetHigh(int shift)
{
return(ArrHigh[shift]);
}
//****************************************************************************//
//Function CMqlHeikenAshi.GetLow
double CMqlHeikenAshi::GetLow(int shift)
{
return(ArrLow[shift]);
}
//****************************************************************************//
//Function CMqlHeikenAshi.GetClose
double CMqlHeikenAshi::GetClose(int shift)
{
return(ArrClose[shift]);
}
//****************************************************************************//
//Function CMqlHeikenAshi.GetTimeframe
ENUM_TIMEFRAMES CMqlHeikenAshi::GetTimeframe()
{
return(WorkPeriod);
}
//****************************************************************************//
//Function CMqlHeikenAshi.GetSymbol
string CMqlHeikenAshi::GetSymbol()
{
return(WorkSymbol);
}
//****************************************************************************//
//Function CMqlHeikenAshi.GetTimeframeName
string CMqlHeikenAshi::GetTimeframeName()
{

  switch(WorkPeriod)
  {
  case PERIOD_M1:  return("M1");
  case PERIOD_M2:  return("M2");
  case PERIOD_M3:  return("M3");
  case PERIOD_M4:  return("M4");
  case PERIOD_M5:  return("M5");
  case PERIOD_M6:  return("M6");
  case PERIOD_M10: return("M10");
  case PERIOD_M12: return("M12");
  case PERIOD_M15: return("M15");
  case PERIOD_M20: return("M20");
  case PERIOD_M30: return("M30");
  case PERIOD_H1:  return("H1");
  case PERIOD_H2:  return("H2");
  case PERIOD_H3:  return("H3");
  case PERIOD_H4:  return("H4");
  case PERIOD_H6:  return("H6");
  case PERIOD_H8:  return("H8");
  case PERIOD_H12: return("H12");
  case PERIOD_D1:  return("Daily");
  case PERIOD_W1:  return("Weekly");
  case PERIOD_MN1: return("Monthly");
  }
//----------------------------------------------------------------------------//
return("UNKNOWN_PERIOD");
//----------------------------------------------------------------------------//
}
////////////////////////////////////////////////////////////////////////////////
